==> noahs-2.0.4.tar.gz: noahs/src/WidgetBase.php <==
<?php 

namespace Drupal\noahs_page_builder;
use Drupal\noahs_page_builder\Controller\NoahsSaveStylesController;

class WidgetBase {

  public function twig(){
    return \Drupal::service('twig');
  }

  public function wrapper($data, $content) {

      $config = \Drupal::config('noahs_page_builder.settings');

      $divider_declaration = '';
      
      $settings = !empty($data->settings->element) ? $data->settings->element : null;

      if(!empty($settings->css->desktop->default->bg_divider)){
        $dividers = $settings->css->desktop->default->bg_divider;
      
        foreach($dividers as $k => $divider){
    
              if(!empty($divider->divider)){
                if($k === 'bottom'){
                  $divider_declaration .= '<div class="noahs-divider-svg bottom">';
                }
                if($k === 'top'){
                  $divider_declaration .= '<div class="noahs-divider-svg top">';

                }
              $divider_declaration .= file_get_contents($divider->divider);
              $divider_declaration .= '</div>';
            }
        }
      
      }

      $element = 'div';
      $class = ['noahs_page_builder-widget', 'widget-'. str_replace('_', '-', $data->type)];
      $subclass = ['widget-wrapper', 'element-transition'];
      $widget_default = 'element';
      $column_size = null;
      $obj = new \stdClass();
      $obj->settings = new \stdClass();

      $global_class =  !empty($data->global) ? 'widget-global' : '';
      $tabs = "<ul class='noahs_page_builder-widget-action-tabs tab-{$data->type} $global_class'>";
      $id = !empty($data->wid) ? $data->wid : uniqid();
      $uid =\Drupal::currentUser()->id();

      $fields = noahs_page_builder_get_widget_fields($data->type);
      $widgetData = noahs_page_builder_get_widget_data($data->type);
      $widget_title = $widgetData['title'];

      $tabs .= "<li class='widget_type'><span>$widget_title</span></li>";
      $tabs .= "<li><div class='area_tooltip noahs_page_builder-edit-widget' title='Edit' data-widget-id='$id'><i class='fa-solid fa-pen-to-square'></i></div></li>";
      $column_size = $data->column_size ?? null;
      if($data->type === 'noahs_row'){
        $element = 'section';
        $widget_default = 'section';
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-add-column' title='Add Column' data-widget-id='$id'><i class='fa-solid fa-plus'></i></div></li>";
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-move-section' title='Move' data-widget-id='$id'><i class='fa-solid fa-up-down-left-right'></i></div></li>";
        
      }else if($data->type === 'noahs_column'){
        $widget_default = 'column';
      
        // $class[] = 'col-xs-12';
  
        // array_push($class, $column_size);
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-add-element-widget' title='Add Widget' data-widget-id='$id'><i class='fa-solid fa-plus'></i></div></li>";
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-move-column' title='Move' data-widget-id='$id'><i class='fa-solid fa-up-down-left-right'></i></div></li>";

      }else{
        $class[] = 'element-widget';
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-move-widget' title='Move' data-widget-id='$id'><i class='fa-solid fa-up-down-left-right'></i></div></li>";
      }
 
      $class[] = 'scrollme';
     
      $tabs .= "<li><div class='area_tooltip noahs_page_builder-remove-widget' title='Remove' data-widget-id='$id'><i class='fa-solid fa-trash'></i></div></li>";
      $tabs .= "<li><div class='area_tooltip noahs_page_builder-up-widget' title='Up' data-widget-id='$id'><i class='fa-solid fa-arrow-up'></i></div></li>";
      $tabs .= "<li><div class='area_tooltip noahs_page_builder-down-widget' title='Down' data-widget-id='$id'><i class='fa-solid fa-arrow-down'></i></div></li>";
      $tabs .= "<li><div class='area_tooltip noahs_page_builder-clone-widget' title='Clone' data-widget-id='$id'><i class='fa-solid fa-clone'></i></div></li>";
      $tabs .= '<li><div class="dropdown">
      <div class="dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
        <i class="fa-solid fa-ellipsis-vertical"></i>
      </div>';
      $tabs .= '<ul class="dropdown-menu p-0" aria-labelledby="navbarDropdown">
        <li class="d-block"><div class="dropdown-item d-block noahs_copy_element">Copy</div></li>';
        if(is_module_installed('noahs_page_builder_pro')) {
          if($data->type != 'noahs_row' && $data->type != 'noahs_column' && empty($global_class)){
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_save_as_global">'. t('Save as Global') .'</div></li>';
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_save_as_default">'. t('Save as Default') .'</div></li>';
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_copy_style_element">Copy Config</div></li>';
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_paste_style_element">Paste Config</div></li>';
          }
          if(!empty($global_class)){
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_remove_as_global">Detach as Global</div></li>';
          }

          if($data->type === 'noahs_row'){
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_save_as_theme">Save as Theme</div></li>';
          }
        }
        if($data->type === 'noahs_column' || $data->type === 'noahs_row'){
          $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_paste_element">Paste</div></li>';
        }

      $tabs .= '</ul>
      </div></li>';
      $tabs .= '</ul>';
      $widget_class = '';
      $class = implode(' ', $class);
      $subclass = implode(' ', $subclass);
      $route = \Drupal::routeMatch()->getRouteName();

  
      // default object when add new widget
      if(empty($data->settings->wid)){
        $data->settings->wid = !empty($data->wid) ? $data->wid : uniqid();
        $data->settings->did = $data->did;
        $data->settings->type = $data->type; 
      }

      $obj->settings->element = !empty($data->settings->element) ? $data->settings->element : []; 

  
      $html_tabs = '';
      $data_setting = '';
      $widgetStyles = '';
      $data_global = !empty($data->global) ? 'data-widget-global="true"' : null;

      if ($route === 'noahs_page_builder.preview' || 
          $route === 'noahs_page_builder.widget' || 
          $route === 'noahs_page_builder_pro.iframe' || 
          $route === 'noahs_page_builder.product_preview' || 
          $route === 'noahs_page_builder_pro.get_theme' || 
          $route === 'noahs_page_builder.regenerate_widget' || 
          $route === 'noahs_page_builder_pro.get_global_widget' || 
          $route === 'noahs_page_builder_pro.get_default_widget' || 
          $route === 'noahs_page_builder.final_widget'
          ){
        
       $data_setting = !empty($data->settings) ? $data->settings : $obj;
       $data_setting = ' data-settings="'.htmlspecialchars(json_encode($data_setting), ENT_QUOTES, 'UTF-8').'"';
       
  
       $efw = !empty($data->settings) ? json_decode(json_encode($data->settings), true) : json_decode(json_encode($obj), true);
   
       $inlineCSS = new NoahsSaveStylesController;
       $widgetStyles = '<style id="w_style_'.$data->wid.'">' . $inlineCSS->generateWidgetStyles($efw) . '</style>';
      }else{

     
        $tabs = '';
      }




      return '
          <'.$element.' 
          class="'.$class.'" 
          data-widget-type="'.$widget_default.'" 
          id="widget-id-'.$id.'" 
          data-widget-id="'.$id.'" 
          '.($column_size ? 'data-column-size="'.$column_size.'"' : '').'
          data-type="'.$data->type.'" 
          ' . $data_setting . '
          ' . $data_global . '
          >
          ' . $tabs . '
          ' . $divider_declaration . '
          <div class="'.$subclass.'">
                  ' . $content . '
          </div>
          ' . $widgetStyles . '
          </'.$element.'>
      ';
    }

 
}

==> noahs-2.0.5.tar.gz: noahs/src/WidgetBase.php <==
<?php 

namespace Drupal\noahs_page_builder;
use Drupal\noahs_page_builder\Controller\NoahsSaveStylesController;

class WidgetBase {

  public function twig(){
    return \Drupal::service('twig');
  }

  public function wrapper($data, $content) {

      $config = \Drupal::config('noahs_page_builder.settings');

      $divider_declaration = '';
      
      $settings = !empty($data->settings->element) ? $data->settings->element : null;

      if(!empty($settings->css->desktop->default->bg_divider)){
        $dividers = $settings->css->desktop->default->bg_divider;
      
        foreach($dividers as $k => $divider){
    
              if(!empty($divider->divider)){
                if($k === 'bottom'){
                  $divider_declaration .= '<div class="noahs-divider-svg bottom">';
                }
                if($k === 'top'){
                  $divider_declaration .= '<div class="noahs-divider-svg top">';

                }
              $divider_declaration .= file_get_contents($divider->divider);
              $divider_declaration .= '</div>';
            }
        }
      
      }

      $element = 'div';
      $class = ['noahs_page_builder-widget', 'widget-'. str_replace('_', '-', $data->type)];
      $subclass = ['widget-wrapper', 'element-transition'];
      $widget_default = 'element';
      $column_size = null;
      $obj = new \stdClass();
      $obj->settings = new \stdClass();

      $global_class =  !empty($data->global) ? 'widget-global' : '';
      $tabs = "<ul class='noahs_page_builder-widget-action-tabs tab-{$data->type} $global_class'>";
      $id = !empty($data->wid) ? $data->wid : uniqid();
      $uid = \Drupal::currentUser()->id();

      $fields = noahs_page_builder_get_widget_fields($data->type);
      $widgetData = noahs_page_builder_get_widget_data($data->type);
      $widget_title = $widgetData['title'];

      $tabs .= "<li class='widget_type'><span>$widget_title</span></li>";
      $tabs .= "<li><div class='area_tooltip noahs_page_builder-edit-widget' title='Edit' data-widget-id='$id'><i class='fa-solid fa-pen-to-square'></i></div></li>";
      $column_size = $data->column_size ?? null;
      if($data->type === 'noahs_row'){
        $element = 'section';
        $widget_default = 'section';
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-add-column' title='Add Column' data-widget-id='$id'><i class='fa-solid fa-plus'></i></div></li>";
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-move-section' title='Move' data-widget-id='$id'><i class='fa-solid fa-up-down-left-right'></i></div></li>";
        
      }else if($data->type === 'noahs_column'){
        $widget_default = 'column';
      
        // $class[] = 'col-xs-12';
  
        // array_push($class, $column_size);
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-add-element-widget' title='Add Widget' data-widget-id='$id'><i class='fa-solid fa-plus'></i></div></li>";
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-move-column' title='Move' data-widget-id='$id'><i class='fa-solid fa-up-down-left-right'></i></div></li>";

      }else{
        $class[] = 'element-widget';
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-move-widget' title='Move' data-widget-id='$id'><i class='fa-solid fa-up-down-left-right'></i></div></li>";
      }
 
      $class[] = 'scrollme';
     
      $tabs .= "<li><div class='area_tooltip noahs_page_builder-remove-widget' title='Remove' data-widget-id='$id'><i class='fa-solid fa-trash'></i></div></li>";
      $tabs .= "<li><div class='area_tooltip noahs_page_builder-up-widget' title='Up' data-widget-id='$id'><i class='fa-solid fa-arrow-up'></i></div></li>";
      $tabs .= "<li><div class='area_tooltip noahs_page_builder-down-widget' title='Down' data-widget-id='$id'><i class='fa-solid fa-arrow-down'></i></div></li>";
      if(empty($global_class)){
        $tabs .= "<li><div class='area_tooltip noahs_page_builder-clone-widget' title='Clone' data-widget-id='$id'><i class='fa-solid fa-clone'></i></div></li>";
      }
      $tabs .= '<li><div class="dropdown">
      <div class="dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
        <i class="fa-solid fa-ellipsis-vertical"></i>
      </div>';
      $tabs .= '<ul class="dropdown-menu p-0" aria-labelledby="navbarDropdown">';
        if(empty($global_class)){
          $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_copy_element">Copy</div></li>';
        }
        if(is_module_installed('noahs_page_builder_pro')) {
          if($data->type != 'noahs_row' && $data->type != 'noahs_column' && empty($global_class)){
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_save_as_global">'. t('Save as Global') .'</div></li>';
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_save_as_default">'. t('Save as Default') .'</div></li>';
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_copy_style_element">Copy Config</div></li>';
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_paste_style_element">Paste Config</div></li>';
          }
          if(!empty($global_class)){
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_remove_as_global">Detach as Global</div></li>';
          }

          if($data->type === 'noahs_row'){
            $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_save_as_theme">Save as Theme</div></li>';
          }
        }
        if($data->type === 'noahs_column' || $data->type === 'noahs_row'){
          $tabs .= '<li class="d-block"><div class="dropdown-item d-block noahs_paste_element">Paste</div></li>';
        }

      $tabs .= '</ul>
      </div></li>';
      $tabs .= '</ul>';
      $widget_class = '';
      $class = implode(' ', $class);
      $subclass = implode(' ', $subclass);
      $route = \Drupal::routeMatch()->getRouteName();

  
      // default object when add new widget
      if(empty($data->settings->wid)){
        $data->settings->wid = !empty($data->wid) ? $data->wid : uniqid();
        $data->settings->did = $data->did;
        $data->settings->type = $data->type; 
      }

      $obj->settings->element = !empty($data->settings->element) ? $data->settings->element : []; 

  
      $html_tabs = '';
      $data_setting = '';
      $widgetStyles = '';
      $data_global = !empty($data->global) ? 'data-widget-global="true"' : null;

      if ($route === 'noahs_page_builder.preview' || 
          $route === 'noahs_page_builder.widget' || 
          $route === 'noahs_page_builder_pro.iframe' || 
          $route === 'noahs_page_builder.product_preview' || 
          $route === 'noahs_page_builder_pro.get_theme' || 
          $route === 'noahs_page_builder.regenerate_widget' || 
          $route === 'noahs_page_builder_pro.get_global_widget' || 
          $route === 'noahs_page_builder_pro.get_default_widget' || 
          $route === 'noahs_page_builder.final_widget'
          ){
        
       $data_setting = !empty($data->settings) ? $data->settings : $obj;
       $data_setting = ' data-settings="'.htmlspecialchars(json_encode($data_setting), ENT_QUOTES, 'UTF-8').'"';
       
  
       $efw = !empty($data->settings) ? json_decode(json_encode($data->settings), true) : json_decode(json_encode($obj), true);
   
       $inlineCSS = new NoahsSaveStylesController;
       $widgetStyles = '<style id="w_style_'.$data->wid.'">' . $inlineCSS->generateWidgetStyles($efw) . '</style>';
      }else{

     
        $tabs = '';
      }




      return '
          <'.$element.' 
          class="'.$class.'" 
          data-widget-type="'.$widget_default.'" 
          id="widget-id-'.$id.'" 
          data-widget-id="'.$id.'" 
          '.($column_size ? 'data-column-size="'.$column_size.'"' : '').'
          data-type="'.$data->type.'" 
          ' . $data_setting . '
          ' . $data_global . '
          >
          ' . $tabs . '
          ' . $divider_declaration . '
          <div class="'.$subclass.'">
                  ' . $content . '
          </div>
          ' . $widgetStyles . '
          </'.$element.'>
      ';
    }

 
}
